
/******************************************************************************
 *
 *  CFileWndTask.c
 *
 *	File window task methods for the SignWriter key editor.
 *
 *  Copyright 1995 The Center for Sutton Movement Writing. All rights reserved.
 *
 ******************************************************************************/
 


#include "CFileWndTask.h"
#include "CFileWndKeys.h"
#include "Keys.h"




/*** Global Variables ***/

extern void		*gClipRec;			/* Clipboard */
extern void		*gScratchRec;

extern ObjType	 gClipType;
extern ObjType	 gScratchType;




/********************************  Clear  **********************************/


/***
 * IFileWndClear
 *
 ***/
 
void CFileWndClear::IFileWndClear (short nameIndex, CFileWndKeys *pane, Byte keyCode)

{
	CTask::ITask(nameIndex);
	
	itsKeyPane = pane;
	itsKeyCode = keyCode;
}	
	


/***
 * Do (override)
 *
 *	Move current selection to the global scratch record.
 *  Duplicate it, clear the resulting copy, and
 *  update the selection with the cleared copy.
 *
 ***/

void CFileWndClear::Do()

{
	void  *rec;
	
	if (gScratchRec != NULL)
		DisposKey(gScratchType, gScratchRec);
	
	itsKeyPane->GetKey(itsKeyCode, &gScratchRec);
	itsKeyPane->GetKeyType(&gScratchType);

	itsKeyPane->CopyKey(gScratchRec, &rec);
	itsKeyPane->ClearKey(rec);
	itsKeyPane->SetKey(itsKeyCode, rec);
					
	itsKeyPane->UpdateKey(itsKeyCode);	

}
		


/***
 * Undo (override)
 *
 *	Exchange the cleared selection
 *  with the global scratch record.
 *  Re-highlight the selection.
 *
 ***/

void CFileWndClear::Undo()

{
	void  *rec;
	
	itsKeyPane->GetKey(itsKeyCode, &rec);
	itsKeyPane->SetKey(itsKeyCode, gScratchRec);
	gScratchRec = rec;
					
	itsKeyPane->UpdateKey(itsKeyCode);	

}
	


/***
 * Redo (override)
 *
 *	Re-exchange the global scratch
 *  record with the cleared selection.
 *
 ***/

void CFileWndClear::Redo()

{
	void  *rec;
	
	itsKeyPane->GetKey(itsKeyCode, &rec);
	itsKeyPane->SetKey(itsKeyCode, gScratchRec);
	gScratchRec = rec;
					
	itsKeyPane->UpdateKey(itsKeyCode);
		
}




/********************************  Paste  **********************************/


/***
 * IFileWndPaste
 *
 ***/
 
void CFileWndPaste::IFileWndPaste (CFileWndKeys *pane, Byte keyCode)

{
	CTask::ITask(iPASTE);
	
	itsKeyPane = pane;
	itsKeyCode = keyCode;
	
}	



/***
 * Do (override)
 *
 *	Move target selection to the global scratch record.
 *  Duplicate the clipboard item and update the target
 *  selection with the resulting copy.
 *
 ***/

void CFileWndPaste::Do()

{
	void  	*rec;
	
	if (gScratchRec != NULL)
		DisposKey(gScratchType, gScratchRec);
	
	itsKeyPane->GetKey(itsKeyCode, &gScratchRec);
	itsKeyPane->GetKeyType(&gScratchType);

	itsKeyPane->CopyKey(gClipRec, &rec);
	itsKeyPane->SetKey(itsKeyCode, rec);
					
	itsKeyPane->UpdateKey(itsKeyCode);	

}	



/***
 * Undo (override)
 *
 *	Exchange the pasted selection
 *  with the global scratch record.
 *  Re-highlight the original selection.
 *
 ***/

void CFileWndPaste::Undo()

{
	void  *rec;
	
	itsKeyPane->GetKey(itsKeyCode, &rec);
	itsKeyPane->SetKey(itsKeyCode, gScratchRec);
	gScratchRec = rec;
					
	itsKeyPane->UpdateKey(itsKeyCode);	

}



/***
 * Redo (override)
 *
 *	Re-exchange the global scratch
 *  record with the pasted selection.
 *
 ***/

void CFileWndPaste::Redo()

{
	void  *rec;
	
	itsKeyPane->GetKey(itsKeyCode, &rec);
	itsKeyPane->SetKey(itsKeyCode, gScratchRec);
	gScratchRec = rec;
					
	itsKeyPane->UpdateKey(itsKeyCode);	


}
